"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const cli_utilities_1 = require("@contentstack/cli-utilities");
const rate_limit_handler_1 = require("../../../utils/rate-limit-handler");
const base_command_1 = require("../../../base-command");
const interactive_1 = require("../../../utils/interactive");
const common_utilities_1 = require("../../../utils/common-utilities");
class SetRateLimitCommand extends base_command_1.BaseCommand {
    async run() {
        var _a, _b, _c;
        if (!(0, cli_utilities_1.isAuthenticated)()) {
            const err = { errorMessage: 'You are not logged in. Please login with command $ csdx auth:login' };
            cli_utilities_1.cliux.print(err.errorMessage, { color: 'red' });
            this.exit(1);
        }
        const { flags } = await this.parse(SetRateLimitCommand);
        let { org, utilize, 'limit-name': limitName } = flags;
        const config = { org: '', limitName: common_utilities_1.limitNamesConfig, host: this.cmaHost };
        if (!org) {
            org = await (0, interactive_1.askOrgID)();
        }
        config.org = org;
        config.default = flags.default;
        if (utilize) {
            const utilizeValues = (_a = utilize === null || utilize === void 0 ? void 0 : utilize.split(',')) === null || _a === void 0 ? void 0 : _a.map((u) => Number(u.trim()));
            if (utilizeValues.some((u) => isNaN(u) || u < 0 || u > 100)) {
                cli_utilities_1.cliux.error('Utilize percentages must be numbers between 0 and 100.');
                return;
            }
            if ((limitName === null || limitName === void 0 ? void 0 : limitName.length) > 0 && ((_c = (_b = limitName[0]) === null || _b === void 0 ? void 0 : _b.split(',')) === null || _c === void 0 ? void 0 : _c.length) !== utilizeValues.length) {
                cli_utilities_1.cliux.error('The number of utilization percentages must match the number of limit names provided.');
                return;
            }
            else {
                config.utilize = utilize.split(',').map((v) => v.trim());
            }
        }
        if (limitName) {
            const invalidLimitNames = limitName[0].split(',').map((name) => name.trim());
            if (invalidLimitNames.some((name) => !common_utilities_1.limitNamesConfig.includes(name))) {
                cli_utilities_1.cliux.error(`Invalid limit names provided: ${invalidLimitNames.join(', ')}`);
                return;
            }
            else {
                config['limit-name'] = limitName[0].split(',').map((n) => n.trim());
            }
        }
        const limitHandler = new rate_limit_handler_1.RateLimitHandler();
        const managementAPIClient = await (0, cli_utilities_1.managementSDKClient)(config);
        limitHandler.setClient(managementAPIClient);
        try {
            await limitHandler.setRateLimit(config);
        }
        catch (error) {
            cli_utilities_1.cliux.error(`Error: Something went wrong while setting rate limit for org: ${org}`);
            cli_utilities_1.cliux.error(error);
        }
    }
}
exports.default = SetRateLimitCommand;
SetRateLimitCommand.description = 'Set rate-limit for CLI';
SetRateLimitCommand.flags = {
    org: cli_utilities_1.flags.string({
        description: 'Provide the organization UID',
    }),
    utilize: cli_utilities_1.flags.string({
        description: 'Provide the utilization percentages for rate limit, separated by commas',
        default: '50',
    }),
    'limit-name': cli_utilities_1.flags.string({
        description: "[Optional] Provide the limit names separated by commas ['limit', 'getLimit', 'bulkLimit']",
        multiple: true,
    }),
    default: cli_utilities_1.flags.boolean({
        default: false,
        description: 'Reset to default rate limit',
    }),
};
SetRateLimitCommand.examples = [
    '$ csdx config:set:rate-limit --org <<org_uid>>',
    '$ csdx config:set:rate-limit --org <<org_uid>> --utilize 70,80 --limit-name getLimit,limit',
    '$ csdx config:set:rate-limit --org <<org_uid>> --default',
];
